==> python-median-1.1.2.tar.gz: python-median-1.1.2/src/median/auth.py <==
from peewee import DoesNotExist
from .models import User
from .database import crypte
import logging

logger = logging.getLogger('median')
    

def check_auth(user, passwd):
    """
    Check authentication
    
    return True if correct
    """
    try:
        usr = User.get(username=user, password=crypte(passwd))
        logger.info('User "%s" found' % user)
    except DoesNotExist:
        logger.warning('User"%s" not found!' % user)
        return False

    return True 


def check_badge(badge):
    """
    Check authentication with badge only
    
    return True if correct
    """
    try:
        usr = User.get(badge=badge)
        logger.info('Badge "%s" found' % badge)
    except DoesNotExist:
        logger.warning('Badge "%s" not found!' % badge)
        return False

    return True 


def user_auth(user, passwd):
    """
    Vérifie l'authentification de l'utilisateur
    
    :param user: Utilisateur de median
    :type  user: str
    :param passwd: Mot de passe de l'utilisateur
    :type  passwd: str
    :return: id of user, otherwise 0
    :rtype: int
    """
    try:
        usr = User.get(username=user, password=crypte(passwd))
        logger.info('User "%s" found' % user)
    except DoesNotExist:
        logger.warning('User "%s" not found!' % user)
        return 0

    return usr.pk


def user_badge(badge):
    """
    Vérifie l'authentification de l'utilisateur par son badge
    
    :param badge: Code du badge utilisateur
    :type  badge: str
    :return: id of user, otherwise 0
    :rtype: int
    """
    try:
        usr = User.get(badge=badge)
        logger.info('Badge "%s" found' % badge)
    except DoesNotExist:
        logger.warning('Badge "%s" not found' % badge)
        return 0

    return usr.pk

==> python-median-1.1.3.tar.gz: python-median-1.1.3/src/median/auth.py <==
from peewee import DoesNotExist
from .models import User
from .database import crypte
import logging

logger = logging.getLogger('median')


def check_auth(user, passwd):
    """
    Check authentication

    return True if correct
    """
    try:
        usr = User.get(username=user, password=crypte(passwd))
        logger.info('User "%s" found' % user)
    except DoesNotExist:
        logger.warning('User"%s" not found!' % user)
        return False

    return True


def check_badge(badge):
    """
    Check authentication with badge only

    return True if correct
    """
    try:
        usr = User.get(badge=badge)
        logger.info('Badge "%s" found' % badge)
    except DoesNotExist:
        logger.warning('Badge "%s" not found!' % badge)
        return False

    return True


def user_auth(user, passwd):
    """
    Check the authentification for the user with:
    - Username
    - Login
    - Email

    :param user: Utilisateur de median
    :type  user: str
    :param passwd: Mot de passe de l'utilisateur
    :type  passwd: str
    :return: id of user, otherwise 0
    :rtype: int
    """
    try:
        usr = User.select().where(
            ((User.username == user) | (User.email == user) | (User.login == user)),
            User.password == crypte(passwd)).get()
        logger.info('User "%s" found' % user)
    except DoesNotExist:
        logger.warning('User "%s" not found!' % user)
        return 0

    return usr.pk


def user_badge(badge):
    """
    Vérifie l'authentification de l'utilisateur par son badge

    :param badge: Code du badge utilisateur
    :type  badge: str
    :return: id of user, otherwise 0
    :rtype: int
    """
    try:
        usr = User.get(badge=badge)
        logger.info('Badge "%s" found' % badge)
    except DoesNotExist:
        logger.warning('Badge "%s" not found' % badge)
        return 0

    return usr.pk
